@@ -455,7 +455,14 @@ break your code.
 
 You can enable this setting temporarily by setting the HYPOTHESIS_STRICT_MODE
 environment variable to the string 'true'.
-"""
+""",
+    deprecation_message="""
+Strict mode is deprecated and will go away in a future version of Hypothesis.
+
+To get the same behaviour, use
+warnings.simplefilter('error', HypothesisDeprecationWarning).
+""",
+    future_default=False,
 )
 
 settings.define_setting(
@@ -576,7 +583,10 @@ def _validate_phases(phases):
 settings.define_setting(
     'phases',
     default=tuple(Phase),
-    description='Control which phases should be run',
+    description=(
+        'Control which phases should be run. ' +
+        'See :ref:`the full documentation for more details <phases>`'
+    ),
     validator=_validate_phases,
 )
 
@@ -620,18 +630,10 @@ assert settings.default is not None
 
 
 def note_deprecation(message, s=None):
-    # If *either* self or the current default are non-strict
-    # then this should be an error. This is to handle e.g. the case
-    # where defining a new setting while non-strict updates a
-    # profile which is strict. This should not be an error, but
-    # using the profile here would cause it to be one.
     if s is None:
         s = settings.default
     assert s is not None
-    strict = settings.default.strict and s.strict
     verbosity = s.verbosity
     warning = HypothesisDeprecationWarning(message)
-    if strict:
-        raise warning
-    elif verbosity > Verbosity.quiet:
+    if verbosity > Verbosity.quiet:
         warnings.warn(warning, stacklevel=3)
