@@ -68,6 +68,9 @@ class DeferredStrategy(SearchStrategy):
     def calc_is_empty(self):
         return self.wrapped_strategy.is_empty
 
+    def calc_has_reusable_values(self):
+        return self.wrapped_strategy.has_reusable_values
+
     def __repr__(self):
         if self.__wrapped_strategy is not None:
             if self.__in_repr:
@@ -83,4 +86,4 @@ class DeferredStrategy(SearchStrategy):
             )
 
     def do_draw(self, data):
-        return self.wrapped_strategy.do_draw(data)
+        return data.draw(self.wrapped_strategy)
